pub enum AuthScheme {
None,
Bearer,
Jwt {
issuer: String,
jwks_dir: PathBuf,
},
}Expand description
Authentication scheme for gRPC connections
Variants
None
No authentication
Bearer
A static bearer token is attached to each request
Jwt
JWT tokens are attached to each request (these have an iss field that
matches the issuer, an aud field that matches the method being
requested, and are signed with an ES256 key that has been registered
with the emulator)