list_emulators

Function list_emulators 

pub async fn list_emulators() -> Result<Vec<Emulator>>
Enumerates all running emulators that are discoverable via ADB and returns their metadata

This is useful for finding emulators that were launched outside of this library, such as those launched by Android Studio. It reads the emulator metadata from the discovery path .ini files, which include the gRPC port and authentication settings.

This does not connect to any emulators; use connect() on one of the returned instance to establish a gRPC connection.