Module proto

Module proto 

Generated gRPC protocol bindings

Modules

audio_format
Nested message and enum types in AudioFormat.
battery_state
Nested message and enum types in BatteryState.
brightness_value
Nested message and enum types in BrightnessValue.
display_configuration
Nested message and enum types in DisplayConfiguration.
emulator_controller_client
Generated client implementations.
image_format
Nested message and enum types in ImageFormat.
image_transport
Nested message and enum types in ImageTransport.
input_event
Nested message and enum types in InputEvent.
keyboard_event
Nested message and enum types in KeyboardEvent.
log_message
Nested message and enum types in LogMessage.
logcat_entry
Nested message and enum types in LogcatEntry.
notification
Nested message and enum types in Notification.
phone_call
Nested message and enum types in PhoneCall.
phone_response
Nested message and enum types in PhoneResponse.
physical_model_value
Nested message and enum types in PhysicalModelValue.
posture
Nested message and enum types in Posture.
rotation
Nested message and enum types in Rotation.
sensor_value
Nested message and enum types in SensorValue.
touch
Nested message and enum types in Touch.
vm_configuration
Nested message and enum types in VmConfiguration.
vm_run_state
Nested message and enum types in VmRunState.

Structs

AndroidEvent
The android input event system is a framework for handling input from a variety of devices by generating events that describe changes in the state of the devices and forwarding them to user space applications.
AudioFormat
AudioPacket
BatteryState
BootCompletedNotification
BrightnessValue
A single backlight brightness value.
CameraNotification
Fired when the virtual scene camera is activated or deactivated and also in response to the streamNotification call.
ClipData
Representation of a clipped data object on the clipboard.
DisplayConfiguration
A DisplayConfiguration describes a primary or secondary display available to the emulator. The screen aspect ratio cannot be longer (or wider) than 21:9 (or 9:21). Screen sizes larger than 4k will be rejected.
DisplayConfigurations
Provides information about all the displays that can be attached to the emulator. The emulator will always have at least one display.
DisplayConfigurationsChangedNotification
Fired when an update to a display event has been fired through the extended ui. This does not fire events when the display is changed through the console or the gRPC endpoint.
DisplayMode
EmulatorStatus
Entry
EntryList
Fingerprint
FoldedDisplay
The aspect ratio (width/height) will be different from the one where the device is unfolded.
GpsState
Image
ImageFormat
ImageTransport
An ImageTransport allows for specifying a side channel for delivering image frames versus using the standard bytes array that is returned with the gRPC request.
InputEvent
An input event that can be delivered to the emulator.
KeyboardEvent
KeyboardEvent objects describe a user interaction with the keyboard; each event describes a single interaction between the user and a key (or combination of a key with modifier keys) on the keyboard. This follows the pattern as set by (javascript)[https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent\]
LogMessage
LogcatEntry
A parsed logcat entry.
MouseEvent
The MouseEvent interface represents events that occur due to the user interacting with a pointing device (such as a mouse).
Notification
ParameterValue
Pen
A Pen is similar to a touch, with the addition of button and rubber information.
PenEvent
PhoneCall
PhoneNumber
PhoneResponse
PhysicalModelValue
Posture
Must follow the definition in “external/qemu/android/hw-sensors.h”
Rotation
RotationRadian
Rotation angles are relative to the current orientation.
SensorValue
A single sensor value.
SmsMessage
Touch
The Touch interface represents a single contact point on a touch-sensitive device. The contact point is commonly a finger or stylus and the device may be a touchscreen or trackpad.
TouchEvent
A TouchEvent contains a list of Touch objects that are in contact with the touch surface.
Velocity
Velocity is measured in meters per second.
VmConfiguration
Information about the hypervisor that is currently in use.
VmRunState
A Run State that describes the state of the Virtual Machine.
WheelEvent

Enums

DisplayModeValue
in line with android/emulation/resizable_display_config.h