#[repr(i32)]pub enum DeliveryMode {
ModeUnspecified = 0,
ModeRealTime = 1,
}Variants
ModeUnspecified = 0
The audio queue will block and wait until the emulator requests packets. The client does not have to throttle and can push packets at will. This can result in the client falling behind.
ModeRealTime = 1
Audio packets will be delivered in real time (when possible). The audio queue will be overwritten with incoming data if data is made available. This means the client needs to control timing properly, or packets will get overwritten.
Implementations
Sourceimpl DeliveryMode
impl DeliveryMode
Sourceimpl DeliveryMode
impl DeliveryMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.