Module emulator_controller_client

Module emulator_controller_client 

Generated client implementations.

Structs

EmulatorControllerClient
An EmulatorController service lets you control the emulator. Note that this is currently an experimental feature, and that the service definition might change without notice. Use at your own risk!