ImgFormat

Enum ImgFormat 

#[repr(i32)]
pub enum ImgFormat { Png = 0, Rgba8888 = 1, Rgb888 = 2, }

Variants



Png = 0



Rgba8888 = 1

Three-channel RGB color model supplemented with a fourth alpha channel. https://en.wikipedia.org/wiki/RGBA_color_model Each pixel consists of 4 bytes.



Rgb888 = 2

Three-channel RGB color model, each pixel consists of 3 bytes

Implementations

Source

impl ImgFormat

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ImgFormat.

pub fn from_i32(value: i32) -> Option<ImgFormat>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a ImgFormat, or None if value is not a valid variant.

Source

impl ImgFormat

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.