#[repr(i32)]pub enum Response {
Ok = 0,
BadOperation = 1,
BadNumber = 2,
InvalidAction = 3,
ActionFailed = 4,
RadioOff = 5,
}Variants
Ok = 0
BadOperation = 1
Enum out of range
BadNumber = 2
Mal-formed telephone number
InvalidAction = 3
E.g., disconnect when no call is in progress
ActionFailed = 4
Internal error
RadioOff = 5
Radio power off
Implementations
Sourceimpl Response
impl Response
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.