#[repr(i32)]pub enum PostureValue {
PostureUnknown = 0,
PostureClosed = 1,
PostureHalfOpened = 2,
PostureOpened = 3,
PostureFlipped = 4,
PostureTent = 5,
PostureMax = 6,
}Variants
PostureUnknown = 0
PostureClosed = 1
PostureHalfOpened = 2
PostureOpened = 3
PostureFlipped = 4
PostureTent = 5
PostureMax = 6
Implementations
Sourceimpl PostureValue
impl PostureValue
Sourceimpl PostureValue
impl PostureValue
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.