AndroidEvent

Struct AndroidEvent 

pub struct AndroidEvent {
    pub type: i32,
    pub code: i32,
    pub value: i32,
    pub display: i32,
}
The android input event system is a framework for handling input from a variety of devices by generating events that describe changes in the state of the devices and forwarding them to user space applications.

An AndroidEvents will be delivered directly to the kernel as is.

Fields

type: i32

The type of the event. The types of the event are specified by the android kernel. Some examples are: EV_SYN, EV_KEY, EV_SW, etc.. The exact definitions can be found in the input.h header file.

code: i32

The actual code to be send to the kernel. The actual meaning of the code depends on the type definition.

value: i32

The actual value of the event.

display: i32

The display id associated with this input event.