AudioFormat

Struct AudioFormat 

pub struct AudioFormat {
    pub sampling_rate: u64,
    pub channels: i32,
    pub format: i32,
    pub mode: i32,
}

Fields

sampling_rate: u64

Sampling rate to use, defaulting to 44100 if this is not set. Note, that android devices typically will not use a sampling rate higher than 48kHz. See https://developer.android.com/ndk/guides/audio.

channels: i32format: i32mode: i32

[Input Only] The mode used when delivering audio packets.

Implementations

Source

impl AudioFormat

pub fn channels(&self) -> Channels

Returns the enum value of channels, or the default if the field is set to an invalid enum value.

pub fn set_channels(&mut self, value: Channels)

Sets channels to the provided enum value.

pub fn format(&self) -> SampleFormat

Returns the enum value of format, or the default if the field is set to an invalid enum value.

pub fn set_format(&mut self, value: SampleFormat)

Sets format to the provided enum value.

pub fn mode(&self) -> DeliveryMode

Returns the enum value of mode, or the default if the field is set to an invalid enum value.

pub fn set_mode(&mut self, value: DeliveryMode)

Sets mode to the provided enum value.