BatteryState

Struct BatteryState 

pub struct BatteryState {
    pub has_battery: bool,
    pub is_present: bool,
    pub charger: i32,
    pub charge_level: i32,
    pub health: i32,
    pub status: i32,
}

Fields

has_battery: boolis_present: boolcharger: i32charge_level: i32health: i32status: i32

Implementations

Source

impl BatteryState

pub fn charger(&self) -> BatteryCharger

Returns the enum value of charger, or the default if the field is set to an invalid enum value.

pub fn set_charger(&mut self, value: BatteryCharger)

Sets charger to the provided enum value.

pub fn health(&self) -> BatteryHealth

Returns the enum value of health, or the default if the field is set to an invalid enum value.

pub fn set_health(&mut self, value: BatteryHealth)

Sets health to the provided enum value.

pub fn status(&self) -> BatteryStatus

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: BatteryStatus)

Sets status to the provided enum value.