pub struct CameraNotification {
pub active: bool,
pub display: i32,
}Expand description
Fired when the virtual scene camera is activated or deactivated and also in response to the streamNotification call.
Fields
active: boolIndicates whether the camera app was activated or deactivated.
display: i32The display the camera app is associated with.