pub struct DisplayMode {
pub value: i32,
}Fields
value: i32Implementations
Sourceimpl DisplayMode
impl DisplayMode
Sourcepub fn value(&self) -> DisplayModeValue
pub fn value(&self) -> DisplayModeValue
Returns the enum value of value, or the default if the field is set to an invalid enum value.
Sourcepub fn set_value(&mut self, value: DisplayModeValue)
pub fn set_value(&mut self, value: DisplayModeValue)
Sets value to the provided enum value.