EmulatorStatus

Struct EmulatorStatus 

pub struct EmulatorStatus {
    pub version: String,
    pub uptime: u64,
    pub booted: bool,
    pub vm_config: Option<VmConfiguration>,
    pub hardware_config: Option<EntryList>,
    pub heartbeat: u64,
    pub guest_config: HashMap<String, String>,
}

Fields

version: String

The emulator version string.

uptime: u64

The time the emulator has been active in .ms

booted: bool

True if the device has completed booting. For P and later this information will accurate, for older images we rely on adb.

vm_config: Option<VmConfiguration>

The current vm configuration

hardware_config: Option<EntryList>

The hardware configuration of the running emulator as key valure pairs.

heartbeat: u64

Some guests will produce a heart beat, that can be used to detect if the guest is active. This is a monotonically increasing number that gets incremented around once a second.

guest_config: HashMap<String, String>

The configuration of services in the guest, this map contains key value pairs that are specific to the image used by the guest.