GpsState

Struct GpsState 

pub struct GpsState {
    pub passive_update: bool,
    pub latitude: f64,
    pub longitude: f64,
    pub speed: f64,
    pub bearing: f64,
    pub altitude: f64,
    pub satellites: i32,
}

Fields

passive_update: bool

Setting this to false will disable auto updating from the LocationUI, otherwise the location UI will override the location at a frequency of 1hz.

  • This is unused if the emulator is launched with -no-window, or when he location ui is disabled.
  • This will BREAK the location ui experience if it is set to false. For example routing will no longer function.
latitude: f64

The latitude, in degrees.

longitude: f64

The longitude, in degrees.

speed: f64

The speed if it is available, in meters/second over ground

bearing: f64

gets the horizontal direction of travel of this device, and is not related to the device orientation. It is guaranteed to be in the range [0.0, 360.0] if the device has a bearing. 0=North, 90=East, 180=South, etc..

altitude: f64

The altitude if available, in meters above the WGS 84 reference ellipsoid.

satellites: i32

The number of satellites used to derive the fix