ImageFormat

Struct ImageFormat 

pub struct ImageFormat {
    pub format: i32,
    pub rotation: Option<Rotation>,
    pub width: u32,
    pub height: u32,
    pub display: u32,
    pub transport: Option<ImageTransport>,
    pub folded_display: Option<FoldedDisplay>,
    pub display_mode: i32,
}

Fields

format: i32

The (desired) format of the resulting bytes.

rotation: Option<Rotation>

[Output Only] The rotation of the image. The image will be rotated based upon the coarse grained orientation of the device.

width: u32

The (desired) width of the image. When passed as input the image will be scaled to match the given width, while maintaining the aspect ratio of the device. The returned image will never exceed the given width, but can be less. Omitting this value (or passing in 0) will result in no scaling, and the width of the actual device will be used.

height: u32

The (desired) height of the image. When passed as input the image will be scaled to match the given height, while maintaining the aspect ratio of the device. The returned image will never exceed the given height, but can be less. Omitting this value (or passing in 0) will result in no scaling, and the height of the actual device will be used.

display: u32

The (desired) display id of the device. Setting this to 0 (or omitting) indicates the main display.

transport: Option<ImageTransport>

Set this if you wish to use a different transport channel to deliver image frames.

folded_display: Option<FoldedDisplay>

[Output Only] Display configuration when screen is folded. The value is the original configuration before scaling.

display_mode: i32

[Output Only] Display mode when AVD is resizable.

Implementations

Source

impl ImageFormat

pub fn format(&self) -> ImgFormat

Returns the enum value of format, or the default if the field is set to an invalid enum value.

pub fn set_format(&mut self, value: ImgFormat)

Sets format to the provided enum value.

pub fn display_mode(&self) -> DisplayModeValue

Returns the enum value of display_mode, or the default if the field is set to an invalid enum value.

pub fn set_display_mode(&mut self, value: DisplayModeValue)

Sets display_mode to the provided enum value.