ImageTransport

Struct ImageTransport 

pub struct ImageTransport {
    pub channel: i32,
    pub handle: String,
}
An ImageTransport allows for specifying a side channel for delivering image frames versus using the standard bytes array that is returned with the gRPC request.

Fields

channel: i32

The desired transport channel used for delivering image frames. Only relevant when streaming screenshots.

handle: String

Handle used for writing image frames if transport is mmap. The client sets and owns this handle. It can be either a shm region, or a mmap. A mmap should be a url that starts with file:/// Note: the mmap can result in tearing.

Implementations

Source

impl ImageTransport

pub fn channel(&self) -> TransportChannel

Returns the enum value of channel, or the default if the field is set to an invalid enum value.

pub fn set_channel(&mut self, value: TransportChannel)

Sets channel to the provided enum value.