pub struct LogMessage {
pub contents: String,
pub start: i64,
pub next: i64,
pub sort: i32,
pub entries: Vec<LogcatEntry>,
}Fields
contents: String[Output Only] The contents of the log output.
start: i64👎Deprecated
The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer, older output will be overwritten by newer content and the start values will be mismatched.
next: i64👎Deprecated
[Output Only] The position of the next byte of content from the serial console output. Use this value in the next request as the start parameter.
sort: i32Set the sort of response you are interested it in. It the type is “Parsed” the entries field will contain the parsed results. otherwise the contents field will be set.
entries: Vec<LogcatEntry>[Output Only] The parsed logcat entries so far. Only set if sort is set to Parsed
Implementations