pub struct MouseEvent {
pub x: i32,
pub y: i32,
pub buttons: i32,
pub display: i32,
}Expand description
The MouseEvent interface represents events that occur due to the user interacting with a pointing device (such as a mouse).
Fields
x: i32The horizontal coordinate. This is the physical location on the screen For example 0 indicates the leftmost coordinate.
y: i32The vertical coordinate. This is the physical location on the screen For example 0 indicates the top left coordinate.
Indicates which buttons are pressed. 0: No button was pressed 1: Primary button (left) 2: Secondary button (right)
display: i32The display device where the mouse event occurred. Omitting or using the value 0 indicates the main display.