pub struct PhysicalModelValue {
pub target: i32,
pub status: i32,
pub value: Option<ParameterValue>,
}Fields
target: i32status: i32[Output Only]
value: Option<ParameterValue>Value interpretation depends on sensor.
Implementations
Sourceimpl PhysicalModelValue
impl PhysicalModelValue
Sourcepub fn target(&self) -> PhysicalType
pub fn target(&self) -> PhysicalType
Returns the enum value of target, or the default if the field is set to an invalid enum value.
Sourcepub fn set_target(&mut self, value: PhysicalType)
pub fn set_target(&mut self, value: PhysicalType)
Sets target to the provided enum value.
Sourcepub fn status(&self) -> State
pub fn status(&self) -> State
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: State)
pub fn set_status(&mut self, value: State)
Sets status to the provided enum value.