pub struct Posture {
pub value: i32,
}Expand description
Must follow the definition in “external/qemu/android/hw-sensors.h”
Fields
value: i32Implementations
Sourceimpl Posture
impl Posture
Sourcepub fn value(&self) -> PostureValue
pub fn value(&self) -> PostureValue
Returns the enum value of value, or the default if the field is set to an invalid enum value.
Sourcepub fn set_value(&mut self, value: PostureValue)
pub fn set_value(&mut self, value: PostureValue)
Sets value to the provided enum value.