pub struct Rotation {
pub rotation: i32,
pub x_axis: f64,
pub y_axis: f64,
pub z_axis: f64,
}Fields
rotation: i32The rotation of the device, derived from the sensor state of the emulator. The derivation reflects how android observes the rotation state.
x_axis: f64Specifies the angle of rotation, in degrees [-180, 180]
y_axis: f64z_axis: f64Implementations
Sourceimpl Rotation
impl Rotation
Sourcepub fn rotation(&self) -> SkinRotation
pub fn rotation(&self) -> SkinRotation
Returns the enum value of rotation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rotation(&mut self, value: SkinRotation)
pub fn set_rotation(&mut self, value: SkinRotation)
Sets rotation to the provided enum value.