pub struct RotationRadian {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
Rotation angles are relative to the current orientation.
Fields
x: f32Angle of rotation around the x axis in right-handed direction.
y: f32Angle of rotation around the y axis in right-handed direction.
z: f32Angle of rotation around the z axis in right-handed direction.