pub struct SensorValue {
pub target: i32,
pub status: i32,
pub value: Option<ParameterValue>,
}Expand description
A single sensor value.
Fields
target: i32Type of sensor
status: i32[Output Only]
value: Option<ParameterValue>Value interpretation depends on sensor enum.
Implementations
Sourceimpl SensorValue
impl SensorValue
Sourcepub fn target(&self) -> SensorType
pub fn target(&self) -> SensorType
Returns the enum value of target, or the default if the field is set to an invalid enum value.
Sourcepub fn set_target(&mut self, value: SensorType)
pub fn set_target(&mut self, value: SensorType)
Sets target to the provided enum value.
Sourcepub fn status(&self) -> State
pub fn status(&self) -> State
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: State)
pub fn set_status(&mut self, value: State)
Sets status to the provided enum value.