pub struct TouchEvent {
pub touches: Vec<Touch>,
pub display: i32,
}Expand description
A TouchEvent contains a list of Touch objects that are in contact with the touch surface.
Touch events are delivered in sequence as specified in the touchList.
TouchEvents are delivered to the emulated devices using “Protocol B”
Fields
touches: Vec<Touch>The list of Touch objects, note that these do not need to be unique
display: i32The display device where the touch event occurred. Omitting or using the value 0 indicates the main display.