pub struct VmConfiguration {
pub hypervisor_type: i32,
pub number_of_cpu_cores: i32,
pub ram_size_bytes: i64,
}Expand description
Information about the hypervisor that is currently in use.
Fields
hypervisor_type: i32number_of_cpu_cores: i32ram_size_bytes: i64Implementations
Sourceimpl VmConfiguration
impl VmConfiguration
Sourcepub fn hypervisor_type(&self) -> VmHypervisorType
pub fn hypervisor_type(&self) -> VmHypervisorType
Returns the enum value of hypervisor_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_hypervisor_type(&mut self, value: VmHypervisorType)
pub fn set_hypervisor_type(&mut self, value: VmHypervisorType)
Sets hypervisor_type to the provided enum value.