pub struct WheelEvent {
pub dx: i32,
pub dy: i32,
pub display: i32,
}Fields
dx: i32The value indicating how much the mouse wheel is rotated. Scaled so that 120 equals to 1 wheel click. (120 is chosen as a multiplier often used to represent wheel movements less than 1 wheel click. e.g. https://doc.qt.io/qt-5/qwheelevent.html#angleDelta) Positive delta value is assigned to dx when the top of wheel is moved to left. Similarly positive delta value is assigned to dy when the top of wheel is moved away from the user.
dy: i32display: i32The display device where the mouse event occurred. Omitting or using the value 0 indicates the main display.