#[repr(i32)]pub enum EventExpiration {
Unspecified = 0,
NeverExpire = 1,
}Variants
Unspecified = 0
The system will use the default time of 120s to track the touch event with the given identifier. If no update happens within this timeframe the identifier is considered expired and can be made available for re-use. This means that a touch event with pressure 0 for this identifier will be send to the emulator.
NeverExpire = 1
Never expire the given slot. You must ALWAYS close the identifier by sending a touch event with 0 pressure.
Implementations
Sourceimpl EventExpiration
impl EventExpiration
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.