#[repr(i32)]pub enum DisplayFlags {
DisplayflagsUnspecified = 0,
VirtualDisplayFlagPublic = 1,
VirtualDisplayFlagPresentation = 2,
VirtualDisplayFlagSecure = 4,
VirtualDisplayFlagOwnContentOnly = 8,
VirtualDisplayFlagAutoMirror = 16,
}Expand description
These are the set of known android flags and their respective values. you can combine the int values to (de)construct the flags field below.
Variants
DisplayflagsUnspecified = 0
VirtualDisplayFlagPublic = 1
When this flag is set, the virtual display is public. A public virtual display behaves just like most any other display that is connected to the system such as an external or wireless display. Applications can open windows on the display and the system may mirror the contents of other displays onto it. see: https://developer.android.com/reference/android/hardware/display/DisplayManager#VIRTUAL_DISPLAY_FLAG_PUBLIC
VirtualDisplayFlagPresentation = 2
When this flag is set, the virtual display is registered as a presentation display in the presentation display category. Applications may automatically project their content to presentation displays to provide richer second screen experiences. https://developer.android.com/reference/android/hardware/display/DisplayManager#VIRTUAL_DISPLAY_FLAG_PRESENTATION
VirtualDisplayFlagSecure = 4
When this flag is set, the virtual display is considered secure as defined by the Display#FLAG_SECURE display flag. The caller promises to take reasonable measures, such as over-the-air encryption, to prevent the contents of the display from being intercepted or recorded on a persistent medium. see: https://developer.android.com/reference/android/hardware/display/DisplayManager#VIRTUAL_DISPLAY_FLAG_SECURE
VirtualDisplayFlagOwnContentOnly = 8
This flag is used in conjunction with VIRTUAL_DISPLAY_FLAG_PUBLIC. Ordinarily public virtual displays will automatically mirror the content of the default display if they have no windows of their own. When this flag is specified, the virtual display will only ever show its own content and will be blanked instead if it has no windows. See https://developer.android.com/reference/android/hardware/display/DisplayManager#VIRTUAL_DISPLAY_FLAG_OWN_CONTENT_ONLY
VirtualDisplayFlagAutoMirror = 16
Allows content to be mirrored on private displays when no content is being shown. This flag is mutually exclusive with VIRTUAL_DISPLAY_FLAG_OWN_CONTENT_ONLY. If both flags are specified then the own-content only behavior will be applied. see: https://developer.android.com/reference/android/hardware/display/DisplayManager#VIRTUAL_DISPLAY_FLAG_AUTO_MIRROR)
Implementations
Sourceimpl DisplayFlags
impl DisplayFlags
Sourceimpl DisplayFlags
impl DisplayFlags
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.