#[repr(i32)]pub enum ImgFormat {
Png = 0,
Rgba8888 = 1,
Rgb888 = 2,
}Variants
Png = 0
Portable Network Graphics format (https://en.wikipedia.org/wiki/Portable_Network_Graphics)
Rgba8888 = 1
Three-channel RGB color model supplemented with a fourth alpha channel. https://en.wikipedia.org/wiki/RGBA_color_model Each pixel consists of 4 bytes.
Rgb888 = 2
Three-channel RGB color model, each pixel consists of 3 bytes
Implementations
Sourceimpl ImgFormat
impl ImgFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.