pub struct DisplayConfiguration {
pub width: u32,
pub height: u32,
pub dpi: u32,
pub flags: u32,
pub display: u32,
}Expand description
A DisplayConfiguration describes a primary or secondary display available to the emulator. The screen aspect ratio cannot be longer (or wider) than 21:9 (or 9:21). Screen sizes larger than 4k will be rejected.
Common configurations (w x h) are:
- 480p (480x720) 142 dpi
- 720p (720x1280) 213 dpi
- 1080p (1080x1920) 320 dpi
- 4K (2160x3840) 320 dpi
- 4K (2160x3840) 640 dpi (upscaled)
The behavior of the virtual display depends on the flags that are provided to this method. By default, virtual displays are created to be private, non-presentation and unsecure.
Fields
width: u32The width of the display, restricted to: 320 * (dpi / 160) <= width
height: u32The heigh of the display, restricted to:
- 320 * (dpi / 160) <= height
dpi: u32The pixel density (dpi). See https://developer.android.com/training/multiscreen/screendensities for details. This value should be in the range [120, …, 640]
flags: u32A combination of virtual display flags. These flags can be constructed by combining the DisplayFlags enum described above.
The behavior of the virtual display depends on the flags. By default virtual displays are created to be private, non-presentation and unsecure.
display: u32The id of the display. The primary (default) display has the display ID of 0. A secondary display has a display ID not 0.
A display with the id in the range [1, userConfigurable] can be modified. See DisplayConfigurations below for details.
The id can be used to get or stream a screenshot.