pub struct DisplayConfigurations {
pub displays: Vec<DisplayConfiguration>,
pub user_configurable: u32,
pub max_displays: u32,
}Expand description
Provides information about all the displays that can be attached to the emulator. The emulator will always have at least one display.
The emulator usually has the following display configurations: 0: The default display. 1 - 3: User configurable displays. These can be added/removed. For example the standalone emulator allows you to modify these in the extended controls. 6 - 11: Fixed external displays. For example Android Auto uses fixed displays in this range.
Fields
displays: Vec<DisplayConfiguration>user_configurable: u32Display configurations with id [1, userConfigurable] are user configurable, that is they can be added, removed or updated.
max_displays: u32The maximum number of attached displays this emulator supports. This is the total number of displays that can be attached to the emulator.
Note: A display with an id that is larger than userConfigurable cannot be modified.