pub struct Image {
pub format: Option<ImageFormat>,
pub width: u32,
pub height: u32,
pub image: Vec<u8>,
pub seq: u32,
pub timestamp_us: u64,
}Fields
format: Option<ImageFormat>width: u32width is contained in format.
height: u32height is contained in format.
image: Vec<u8>The organization of the pixels in the image buffer is from left to right and bottom up. This will be empty if an alternative image transport is requested in the image format. In that case the side channel should be used to obtain the image data.
seq: u32[Output Only] Monotonically increasing sequence number in a stream of screenshots. The first screenshot will have a sequence of 0. A single screenshot will always have a sequence number of 0. The sequence is not necessarily contiguous, and can be used to detect how many frames were dropped. An example sequence could be: [0, 3, 5, 7, 9, 11].
timestamp_us: u64[Output Only] Unix timestamp in microseconds when the emulator estimates the frame was generated. The timestamp is before the actual frame is copied and transformed. This can be used to calculate variance between frame production time, and frame depiction time.