pub struct ImageTransport {
pub channel: i32,
pub handle: String,
}Expand description
An ImageTransport allows for specifying a side channel for delivering image frames versus using the standard bytes array that is returned with the gRPC request.
Fields
channel: i32The desired transport channel used for delivering image frames. Only relevant when streaming screenshots.
handle: StringHandle used for writing image frames if transport is mmap. The client
sets and owns this handle. It can be either a shm region, or a mmap. A
mmap should be a url that starts with file:/// Note: the mmap can
result in tearing.
Implementations
Sourceimpl ImageTransport
impl ImageTransport
Sourcepub fn channel(&self) -> TransportChannel
pub fn channel(&self) -> TransportChannel
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: TransportChannel)
pub fn set_channel(&mut self, value: TransportChannel)
Sets channel to the provided enum value.