pub struct KeyboardEvent {
pub code_type: i32,
pub event_type: i32,
pub key_code: i32,
pub key: String,
pub text: String,
}Expand description
KeyboardEvent objects describe a user interaction with the keyboard; each event describes a single interaction between the user and a key (or combination of a key with modifier keys) on the keyboard. This follows the pattern as set by (javascript)[https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent\]
Note: that only keyCode, key, or text can be set and that the semantics will slightly vary.
Fields
code_type: i32Type of keycode contained in the keyCode field.
event_type: i32The type of keyboard event that should be sent to the emulator
key_code: i32This property represents a physical key on the keyboard (as opposed to the character generated by pressing the key). In other words, this property is a value which isn’t altered by keyboard layout or the state of the modifier keys. This value will be interpreted by the emulator depending on the KeyCodeType. The incoming key code will be translated to an evdev code type and send to the emulator. The values in key and text will be ignored.
key: StringThe value of the key pressed by the user, taking into consideration the state of modifier keys such as Shift as well as the keyboard locale and layout. This follows the w3c standard used in browsers. You can find an accurate description of valid values here
Note that some keys can result in multiple evdev events that are delivered to the emulator. for example the Key “A” will result in a sequence: [“Shift”, “a”] -> [0x2a, 0x1e] whereas “a” results in [“a”] -> [0x1e].
Not all documented keys are understood by android, and only printable ASCII [32-127) characters are properly translated.
Keep in mind that there are a set of key values that result in android specific behavior see:
- “AppSwitch”: Behaves as the “Overview” button in android.
- “GoBack”: The Back button.
- “GoHome”: The Home button, which takes the user to the phone’s main screen (usually an application launcher).
- “Power”: The Power button.
text: StringSeries of utf8 encoded characters to send to the emulator. An attempt will be made to translate every character will an EvDev event type and send to the emulator as a keypress event. The values in keyCode, eventType, codeType and key will be ignored.
Note that most printable ASCII characters (range [32-127) can be send individually with the “key” param. Do not expect arbitrary UTF symbols to arrive in the emulator (most will be ignored).
Note that it is possible to overrun the keyboard buffer by slamming this endpoint with large quantities of text (>1kb). The clipboard api is better suited for transferring large quantities of text.
Implementations
Sourceimpl KeyboardEvent
impl KeyboardEvent
Sourcepub fn code_type(&self) -> KeyCodeType
pub fn code_type(&self) -> KeyCodeType
Returns the enum value of code_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code_type(&mut self, value: KeyCodeType)
pub fn set_code_type(&mut self, value: KeyCodeType)
Sets code_type to the provided enum value.
Sourcepub fn event_type(&self) -> KeyEventType
pub fn event_type(&self) -> KeyEventType
Returns the enum value of event_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_event_type(&mut self, value: KeyEventType)
pub fn set_event_type(&mut self, value: KeyEventType)
Sets event_type to the provided enum value.