Emulator

Struct Emulator 

pub struct Emulator { /* private fields */ }
Handle to a running emulator instance

This can represent an emulator we spawned with an EmulatorConfig, or an already-running emulator we discovered with list_emulators.

Implementations

Source

impl Emulator

pub fn serial(&self) -> &str

Get the serial number of this emulator (if known)

pub fn is_owned(&self) -> bool

Check if this instance represents an emulator we spawned

pub fn discovery_path(&self) -> &Path

pub fn metadata(&self) -> &HashMap<String, String>

Get a reference to all emulator metadata from the runtime .ini file

pub fn get_metadata(&self, key: &str) -> Option<&str>

Get a specific metadata property value

pub fn requires_jwt_auth(&self) -> bool

Check if this emulator requires JWT authentication

pub fn avd_name(&self) -> Option<&str>

Get the AVD name

pub fn avd_id(&self) -> Option<&str>

Get the AVD ID

pub fn avd_dir(&self) -> Option<&str>

Get the AVD directory path

pub fn emulator_version(&self) -> Option<&str>

Get the emulator version

pub fn emulator_build(&self) -> Option<&str>

Get the emulator build ID

pub fn port_serial(&self) -> Option<u16>

Get the serial port number

pub fn port_adb(&self) -> Option<u16>

Get the ADB port number

pub fn cmdline(&self) -> Option<&str>

Get the command line used to launch the emulator

pub fn grpc_endpoint(&self) -> String

Get the gRPC endpoint URL for this emulator

pub fn grpc_port(&self) -> u16

Get the gRPC port

pub async fn connect( &self, timeout: Option<Duration>, allow_basic_auth: bool, ) -> Result<EmulatorClient>

Connect to the emulator’s gRPC controller

This method will automatically retry the connection if it fails, waiting up to the specified timeout duration. At least one connection attempt is always made before checking the timeout.

Arguments
  • timeout - Maximum time to wait for the connection. If None, will wait indefinitely.
  • allow_basic_auth - If true, will use basic auth (grpc.token / console token) if available.
Errors

Returns an error if JWT authentication setup fails.

pub async fn terminate(&self) -> Result<()>

Terminate the emulator process and wait for it to fully exit

If this instance owns the process (spawned via spawn()), this will kill the process and wait for it to exit.

If this instance was discovered via find(), this returns an error as we don’t own the process.

To terminate a discovered emulator, use ADB commands directly.